# coding=utf-8

from hiword import extract_keywords

docs = [
    "此外，公司拟对全资子公司吉林欧亚置业有限公司增资4.3亿元，增资后，吉林欧亚置业注册资本由7000万元增加到5亿元。吉林欧亚置业主要经营范围为房地产开发及百货零售等业务。目前在建吉林欧亚城市商业综合体项目。2013年，实现营业收入0万元，实现净利润-139.13万元。",
    """早在今年4月，印度政府修改了外商直接投资政策，要求所有来自邻国实体的投资都需要得到政府批准，此举被认为是“意在中国”。上周，印度政府采取进一步行动，禁用59款中国应用程序，其中包括在印度广受欢迎的短视频应用程序Tik Tok。紧接着，就有人呼吁抵制中国的一切事物，甚至包括美食。此类狂热言论掩盖了一个事实，那就是中国企业及其产品已经深入印度。
　　以手机为例，超过8亿印度人在使用中国手机。中国手机已经占据全球第二大智能手机市场，根据市场调研机构Counterpoint Research的数据，印度约有4.95亿的智能手机用户。
　　印度智能手机品牌前五名中有四个是中国品牌，共占据了印度市场73%的份额。小米以30%的市场份额领先，其次是Vivo为17%，Realme（真我）为14%，Oppo为12%。加上其他小品牌，中国企业总共占据了印度市场81%的份额。曾经一度主导印度市场的韩国手机巨头三星，在中国企业面前黯然失色，仅以16%的市场份额位居第三。Counterpoint机构的副总监塔伦·帕塔克（Tarun Pathak）表示，印度智能手机制造商仅占该国市场1%的份额。
　　“印度每售出五部手机中，有四部都是中国品牌。” 帕塔克直言，“其他市场中几乎没有哪个竞争者有这样的掌控力。”
　　与印度本地品牌相比，中国手机品牌价格优惠、外观好看而且技术更先进。当印度公司还在生产3G手机时，中国品牌已推出4G版本。随着需求飞涨，在过去四到五年中，中国智能手机在印度的年平均销售量增长了10%，加上手机及其组件需缴纳进口关税，促使中国企业选择在印度设厂，就地进行组装。与小米手机合作的制造商富士康科技集团，其工厂每年能生产5000万部手机。帕塔克表示，Oppo和Vivo手机紧随其后，年产能分别为4500万部和4000万部。
　　帕塔克补充说，2019年中国企业在印度售出的1.58亿部智能手机中，99%是在本地组装。“这些中国企业不仅在印度销售手机，还给印度人提供了工作，并且进行人才培训。”据帕塔克估计，中国智能手机组装部门在印度直接或间接雇用了约10万人。如果这些工作濒临危机，则可能导致大规模失业。“还有谁有能力雇用这么多人？”帕塔克不禁反问。
　　除手机外，在印度的中国工厂还生产智能手表、电视、无线耳机等产品。帕塔克表示，尽管疫情期间产品销量下降了，但“（企业）生态系统正在蓬勃发展。”""",
    """新华社北京7月9日电 国务院总理李克强7月8日主持召开国务院常务会议，部署进一步做好防汛救灾工作、推进重大水利工程建设，确定持续优化营商环境激发市场主体活力的措施，部署中央预算执行和其他财政收支审计查出问题整改工作。
　　会议指出，今年以来全国累积降水量比常年同期明显偏多且降雨集中，局部地区受灾严重。近期南方大部地区仍有强降雨，据预报下一步雨区会北抬。南北方已全面进入主汛期，防汛将进入“七下八上”关键期。各地各有关部门要贯彻党中央、国务院部署，坚持生命至上，全力做好防汛救灾工作。一是压实各方责任，各级防汛责任人要下沉一线，强化监测预警，加强协调调度。二是切实做好大江大河流域防汛工作，加强中小河流防洪、中小水库除险和城市防涝。针对北方江河多年未来大洪水、防洪设施较薄弱等情况，抓紧部署做好黄淮海和松辽等地区防洪工作，健全会商联防机制，备齐防汛物资，强化水库、堤防等巡查防守，科学调度骨干防洪工程，做好蓄滞洪区运用准备，完善人员撤避预案，及时转移受威胁群众。三是加大物资和资金支持，帮助地方妥善安置受灾群众、开展水毁工程修复和生产自救。同时，做好部分地区抗旱工作和旱涝急转应对。
　　重大水利工程是“两新一重”建设的重要内容。会议围绕防洪减灾、水资源优化配置、水生态保护修复等，研究了今年及后续150项重大水利工程建设安排，要求抓紧推进建设，促进扩大有效投资，增强防御水旱灾害能力。会议强调，要按照市场化、法治化原则，深化投融资体制机制改革，落实水价标准和收费制度，建立合理回报机制，扩大股权和债权融资规模，以市场化改革推动加快水利工程建设。
　　会议指出，要按照“六稳”“六保”工作要求，既立足当前，围绕保上亿市场主体，落实好已部署的财政、社保、金融等规模性纾困政策，又着眼长远，用改革的办法打造市场化法治化国际化营商环境，更大激发市场主体活力。一要强化为市场主体服务。加快推动工程建设项目全流程在线审批。积极探索对需要许可证的行业实行“一证准营”、跨地通用。年内将工业产品生产许可证管理权限下放到省级，将商标注册平均审查周期压缩至4个月以内。二要为就业创业提供便利。完善对新业态的包容审慎监管，引导平台企业降低佣金、条码支付手续费等，促进灵活就业。清理教育、医疗、体育等领域不合理准入条件。明年6月底前实现职称信息在线核验。三要优化外资外贸环境。授权全国地级及以上城市开展外商投资企业注册登记。进出口环节监管证件原则上“单一窗口”一口受理。
　　会议指出，2019年度中央预算执行和其他财政收支审计结果已公布。有关地方和部门要对照查出的问题逐项整改、“对账销号”，并完善相关制度机制。整改结果在向全国人大常委会报告后公开。
　　会议还研究了其他事项。""",
    """
    国务院办公厅7月9日印发《关于推进医疗保障基金监管制度体系改革的指导意见（国办发〔2020〕20号）》（以下简称“意见”）。《意见》提出，将进一步强化医保部门对于医保基金的监管责任，完善公立点医药机构领导班子和领导人员特别是主要负责人监督约束机制，加强对其履行政治责任、基金监管责任的监督考核与执纪问责，筑牢监管底线。
　　《意见》进一步加大了对于欺诈骗保的惩处力度。《意见》提出：严惩重罚欺诈骗保的单位和个人。严格落实全国人大常委会关于欺诈骗保行为的立法解释，对涉嫌犯罪的案件，依法移交司法机关追究刑事责任。
　　公开数据显示，2019年中国基本医疗保险基金总收入、总支出分别为23334.87亿元、19945.73亿元，在医保基金覆盖面和总支出不断增加的同时，骗保案件也时有发生。
　　《2019年医疗保障事业发展统计快报》显示：2019年，各级医保部门共现场检查定点医药机构81.5万家，查处违法违规违约医药机构26.4万家，其中解除医保协议6730家、行政处罚6638家、移交司法机关357家；各地共处理违法违规参保人员3.31万人，暂停结算6595人、移交司法机关1183人；全年共追回资金115.56亿元。
　　《意见》指出，医疗保障基金是人民群众的“看病钱”、“救命钱”，但是，受监管制度体系不健全、激励约束机制不完善等因素制约，医保基金使用效率不高，基金监管形势较为严峻。
　　为进一步加强骗保惩处力度，将综合运用司法、行政、协议等手段，严惩重罚欺诈骗保的单位和个人。严格落实全国人大常委会关于欺诈骗保行为的立法解释，对涉嫌犯罪的案件，依法移交司法机关追究刑事责任。医疗保障部门依法依规加大行政处罚力度。积极发挥部门联动处罚作用，对经医疗保障部门查实、欺诈骗保情节特别严重的定点医药机构，卫生健康、药品监管部门应依法作出停业整顿、吊销执业（经营）资格、从业限制等处罚，提升惩处威慑力。对欺诈骗保情节严重的定点医药机构和个人，纳入失信联合惩戒对象名单，实施联合惩戒。
　　同时，《意见》对于举报骗保行为也明确予以了支持。《意见》提出，统筹地区及以上医疗保障和财政部门应当建立并不断完善医疗保障违法违规违约行为举报奖励制度，依照相关规定对举报人予以奖励。畅通投诉举报渠道，规范受理、检查、处理、反馈等工作流程和机制，加强隐私保护，切实保障举报人信息安全。完善举报奖励标准，及时兑现奖励资金，促进群众和社会各方积极参与监督。""",
    """
    人民网曼谷6月27日电（孙广勇、郝树占）6月26日，东帝汶第3轮国家紧急状态结束，正式转入抗疫防疫与复工复产、发展经济阶段。
　　今年3月以来，新冠肺炎疫情在东帝汶蔓延，从3月28日起，东连续实施3轮国家紧急状态。东帝汶中资企业在国际航线中断，劳动力供给不足和承受较大疫情防控压力的情况下，克服自身困难，力保企业防疫安全，结合东帝汶业主要求，积极开展复工复产，并向东帝汶提供了力所能及的帮助。
　　遵守当地法律法规，做好防疫抗疫工作。东帝汶国力薄弱，卫生防疫条件不足，实施紧急状态措施，切断新冠病毒传播途径是控制疫情的关键环节，也符合东实际情况。虽然紧急状态对企业生产和居民生活尤其是项目施工等带来非常明显的不利影响，但在东中资企业充分理解并积极配合政府和所在社区做好防疫抗疫工作。各企业在我驻东使馆领导和支持下，均制订了特殊时期应急方案；坚持和完善工地、营地、办公场所人员出入管控和应急管理，做细做实员工思想和引导工作，做好物资储备，稳定队伍和人心；在信息跟踪、措施应对、项目管理、人员进出、安全保卫、生活物资采购和供应各环节抓细抓实；与使馆、企业协会保持良好沟通，确保找得到人，说得清事。3个月紧急状态以来，在东中资企业确保了稳定的思想动态，确保了良好的生活秩序，没有出现一例新冠肺炎疑似和确诊病例。
　　履行社会责任，共筑抗疫战线。3个多月来，中资企业在东帝汶国家紧急状态期间，先后向东帝汶医院、学校、社区捐款捐物，协助共同抗击疫情，展示了中国企业高度的社会责任感。4月24日，驻东中资企业协会代表全体中资企业向东帝汶国立医院捐赠2万美元，东国立医院院长深表感谢，称这笔款项是雪中送炭，为该院志愿者提供了急需的支援。4月28日，上海建工东帝汶项目团队紧急搭建的援东物资移动存储仓库在运输包机抵达前顺利完成交接，确保了中国援东抗疫物资包机准时抵达帝力国际机场。在“六一”国际儿童节来临之际，中国水电东帝汶项目部前往当地学校进行慰问，给孩子们送上文具、牛奶、口罩的同时，还详细介绍了日常自我防疫措施。6月13日，山东外经东帝汶公司员工赴拉雷拉（Laleia）公路项目所在地，为沿线30余户居民无偿安装供水管道和设备，帮助当地居民解决了困扰多年的用水难题。6月16日，中国港湾东帝汶公司积极响应东前总统、诺贝尔和平奖获得者奥尔塔先生的募捐倡议，向边远山区的老百姓捐赠了50袋大米，70箱泡面和70L食用油。6月23日，中国石化东帝汶公司向东社会福利部捐赠100包价值1000美元的大米。中国中铁所属中海外-中铁一局东帝汶联营体公司心系东帝汶疫情，主动承担7万美元包机运费，力助中国政府向东帝汶通过包机运输援助防疫物资，中国也成为国际上第一个通过包机方式向东帝汶运送医护物资的国家，体现了中东两国人民的深情厚谊，产生了良好的国际影响，得到了东政府和人民的高度赞扬。
　　统筹疫情防控和生产经营，落实复工复产。5月下旬以来，虽然东帝汶仍处于紧急状态，东帝汶公共工程部向中资企业发来复工复产信函，希望中资企业积极协助政府恢复经济活动。各企业接到请求后，积极与东主管部门沟通，探讨复工复产可行性和计划安排，在认真落实东紧急状态要求，确保员工防疫安全的前提下逐步复工复产。中铁国际集团承建的东帝汶包考-维可可公路项目于5月29日复工。山东外经承建的东帝汶商业银行大楼项目，在员工不足的情况下于6月9日复工。中核二二公司运营的东帝汶国家电网、马拉图托自来水厂项目，在紧急状态期间积极响应东政府保民生号召，现场人员24小时值守，未受疫情影响而停工一天，切实保障了东国民生用电用水的需求和稳定；该公司承建的南部山区萨拉乌至纳塔博纳道路工程，因连续暴雨发生山体滑坡造成道路交通中断，项目部在未复工的情况下，第一时间组织人员和机械设备冒雨施工恢复交通，受到当地民众的好评。上海建工通过项目分级分区施工，防疫和生产两手抓，欧盟资金项目C16标段公路于6月2日提前完工，国家一号公路项目于6月25号全线拉通。中国港湾承建的蒂坝港集装箱项目是中东两国共建“一带一路”重点项目，疫情期间保持较高的开工率，有效保证了项目建设进度，东帝汶环保国务秘书视察该项目时，称赞该公司是服务东国家战略工程的重要企业，对中国港湾专业的环保管理能力高度赞赏，并颁发了环保质量A级证书。
　　人间自有真情在。中资企业扎根东帝汶，服务当地社区，携手东帝汶人民，积极防疫抗疫，体现了中国企业与东帝汶患难与共的最大善意，践行“一带一路”倡议，践行了“人类卫生健康共同体”的共同理念，有力推动了中东经贸合作，切实促进了两国民心相通。在东中资企业坚信，中东两国人民一定会在抗击疫情斗争中更加相互理解、紧密团结，取得战胜疫病的共同胜利。在东中资企业坚信，随着东帝汶政府经济复苏方案逐步出台，中资企业将抓住合作机遇，与东帝汶各方进一步加强合作，不断扩大中东两国经贸合作的规模和内涵，不断推动两国人民世代友好，推进命运共同体建设，为中东友好做出新的贡献。
    """,
    """
    “您的来信已经收到，我们将按照程序对问题进行处置，同时告知您，依法举报是您的权利，举报内容必须实事求是，不得恶意举报，如果进行诬告陷害，将承担相应责任……”6月22日上午，昌邑市纪委监委信访室工作人员对实名来信举报的张某某进行实名信访举报受理“双告知”。
　　《纪检监察机关处理检举控告工作规则》出台后，昌邑市纪委监委从提升工作规范化水平出发，于今年3月起推行实名信访举报受理“双告知”制度，即：告知信访人纪检监察机关信访举报受理范围，业务内信访举报已按照程序受理；并告知信访人要履行举报义务，应当如实提供情况和证据，如果进行诬告陷害，将依规依纪依法严肃处理。
　　“在受理阶段对信访人进行‘双告知’，一方面教育引导信访人依法行使检举权和控告权，减少诬告陷害行为发生；另一方面让信访人‘心中有底’，避免因不确定信访问题是否被受理而出现重复信访、越级信访等问题。”该市纪委监委相关负责人介绍，“截至目前，我们已对47起实名信访举报进行受理‘两告知’，均未出现重复信访问题。”
　　推行“双告知”制度，是昌邑市纪委监委为进一步化解重复信访、越级信访问题采取的众多举措之一。市纪委监委坚持问题导向，在完善制度上下功夫，在精准施策上出实招。今年5月，市纪委监委出台《初信初访首办责任制实施办法（试行）》，压实工作责任，并实行快分办、快处置、快核查、快答复“四快”工作法，推动初信初访件快速办结，避免出现重复信访、越级信访问题。在此基础上，建立信访举报办理质量认证制度，重要信访件办结之前，信访室会同审理室对相关核查材料进行审查，防止出现查得不深不透等问题，提升办理质量。今年以来，已通过质量认证机制预审重要信访举报4件。
　　针对部分信访人存在的“信上不信下”心理，该市纪委监委建立了重复信访复查制度，对需要重新核查的重复信访件，按照不限原调查结论、不限原处理意见、不限原领导表态的“三不限”要求，重新调查，做到不弄清重复信访原因不放过、不提出具体处理意见不放过、不实现“案结事了”不放过，增强信访人对处理结论的认可度。
　　“下步，我们将在完善制度机制的基础上，开展化解信访积案集中行动，持续遏制重复信访、越级信访‘增量’，化解‘存量’，全力推动纪检监察信访举报工作高质量发展。”昌邑市委常委、市纪委书记、市监委主任孔晓明表示。（潍坊市纪委监委 ‖ 责任编辑 黄强）
    """,
    """
    新形势下，我们要坚持和发展中国特色社会主义宗教理论，全面贯彻党的宗教工作基本方针，分析我国宗教工作形势，研究我国宗教工作面临的新情况新问题，全面提高宗教工作水平，更好组织和凝聚广大信教群众同全国人民一道，为实现“两个一百年”奋斗目标、实现中华民族伟大复兴的中国梦而奋斗。
宗教问题始终是我们党治国理政必须处理好的重大问题，宗教工作在党和国家工作全局中具有特殊重要性，关系中国特色社会主义事业发展，关系党同人民群众的血肉联系，关系社会和谐、民族团结，关系国家安全和祖国统一。
我国宗教工作形势总体是好的，党的宗教工作基本方针得到贯彻，党同宗教界的爱国统一战线不断巩固，宗教工作法治化明显加强，宗教活动总体平稳有序。实践证明，我们党关于宗教问题的理论和方针政策是正确的。
做好宗教工作，必须坚持党的宗教工作基本方针，要全面贯彻党的宗教信仰自由政策，依法管理宗教事务，坚持独立自主自办原则，积极引导宗教与社会主义社会相适应。党的宗教工作基本方针是我们党坚持马克思主义宗教观，从我国国情和宗教具体实际出发，汲取正反两方面经验制定出来的。
实行宗教信仰自由政策，出发点和落脚点是要最大限度把广大信教和不信教群众团结起来。积极引导宗教与社会主义社会相适应，是要引导信教群众热爱祖国、热爱人民，维护祖国统一，维护中华民族大团结，服从服务于国家最高利益和中华民族整体利益；拥护中国共产党领导、拥护社会主义制度，坚持走中国特色社会主义道路；积极践行社会主义核心价值观，弘扬中华文化，努力把宗教教义同中华文化相融合；遵守国家法律法规，自觉接受国家依法管理；投身改革开放和社会主义现代化建设，为实现中华民族伟大复兴的中国梦贡献力量。
做好党的宗教工作，把党的宗教工作基本方针坚持好，关键是要在“导”上想得深、看得透、把得准，做到“导”之有方、“导”之有力、“导”之有效，牢牢掌握宗教工作主动权。
做好新形势下宗教工作，就要坚持用马克思主义立场、观点、方法认识和对待宗教，遵循宗教和宗教工作规律，深入研究和妥善处理宗教领域各种问题，结合我国宗教发展变化和宗教工作实际，不断丰富和发展中国特色社会主义宗教理论，用以更好指导我国宗教工作实践。
积极引导宗教与社会主义社会相适应，一个重要的任务就是支持我国宗教坚持中国化方向。要用社会主义核心价值观来引领和教育宗教界人士和信教群众，弘扬中华民族优良传统，用团结进步、和平宽容等观念引导广大信教群众，支持各宗教在保持基本信仰、核心教义、礼仪制度的同时，深入挖掘教义教规中有利于社会和谐、时代进步、健康文明的内容，对教规教义作出符合当代中国发展进步要求、符合中华优秀传统文化的阐释。
要构建积极健康的宗教关系。在我国，宗教关系包括党和政府与宗教、社会与宗教、国内不同宗教、我国宗教与外国宗教、信教群众与不信教群众的关系。促进宗教关系和谐，这些关系都要处理好。
处理我国宗教关系，必须牢牢把握坚持党的领导、巩固党的执政地位、强化党的执政基础这个根本，必须坚持政教分离，坚持宗教不得干预行政、司法、教育等国家职能实施，坚持政府依法对涉及国家利益和社会公共利益的宗教事务进行管理。要提高宗教工作法治化水平，用法律规范政府管理宗教事务的行为，用法律调节涉及宗教的各种社会关系。要保护广大信教群众合法权益，深入开展法治宣传教育，教育引导广大信教群众正确认识和处理国法和教规的关系，提高法治观念。
宗教团体是党和政府团结、联系宗教界人士和广大信教群众的桥梁和纽带，要为他们开展工作提供必要的支持和帮助，尊重和发挥他们在宗教内部事务中的作用，努力建设政治上可信、作风上民主、工作上高效的高素质领导班子。要坚持政治上靠得住、宗教上有造诣、品德上能服众、关键时起作用的标准，支持宗教界搞好人才队伍建设。要坚决抵御境外利用宗教进行渗透，防范宗教极端思想侵害。要高度重视互联网宗教问题，在互联网上大力宣传党的宗教理论和方针政策，传播正面声音。
新形势下，宗教工作范围广、任务重，既要全面推进，也要重点突破。要结合各宗教情况，抓住主要矛盾，解决突出问题，以做好重点工作推进全局工作。
各级党委要提高处理宗教问题能力，把宗教工作纳入重要议事日程，及时研究宗教工作中的重要问题，推动落实宗教工作决策部署。要加强对党关于宗教问题的理论和方针政策的学习，加强对宗教基本知识的学习，把党关于宗教问题的理论和方针政策纳入干部教育培训计划，使各级干部尽可能多地掌握。要建立健全强有力的领导机制，做好对宗教工作的引领、规划、指导、督查。统战部门要负起牵头协调责任，宗教工作部门要担负起依法管理责任，各有关部门及工会、共青团、妇联、科协等人民团体要齐抓共管，共同做好宗教工作。要广泛宣传党关于宗教问题的理论和方针政策，宣传宗教相关法律法规，加强宗教方面宣传舆论引导。党的基层组织特别是宗教工作任务重的地方基层组织，要切实做好宗教工作，加强对信教群众的工作。共产党员要做坚定的马克思主义无神论者，严守党章规定，坚定理想信念，牢记党的宗旨，绝不能在宗教中寻找自己的价值和信念。要加强对青少年的科学世界观宣传教育，引导他们相信科学、学习科学、传播科学，树立正确的世界观、人生观、价值观。
在爱国主义、社会主义旗帜下，同宗教界结成统一战线，是我们党处理宗教问题的鲜明特色和政治优势。要坚持政治上团结合作、信仰上相互尊重，多接触、多谈心、多帮助，以理服人，以情感人，通过解决实际困难吸引人、团结人。
    """,
    """第一条 邮电工作中国家秘密的具体范围包括：
（一）邮电通信发展规划、总体布局、网路组织，邮电通信发展、基建、引进、 财务计划;
(二)	战备通信、机要通信、党政专用通信、边海防通信，为党和国家领导人、外国政府要员提供的通信手段、保障措施，为党政军重要部门特殊需提供的邮电通信保障措施；
(三)	邮电资费调整方案，未公开的邮票、集邮品印量；
(四）	党政专用通信保密措施和密码通信，邮政电汇押密和邮政储汇密码；
(五)	具有国际先进水平的邮电科技成果；
(六）	邮电重要外事活动中的秘密事项。
第二条  邮电工作中国家秘密的密级具体范围如下：
(一) 绝密级事项
1.	国家级战备通信的总体布局、局站分布，枢纽设施、网路组织和通信能力;
2.	为党和国家领导人提供的通信保密措施和密码通信状况。
(二) 机密级事项
1.	全国邮电通信发展重大策略及规划；
2.	全国邮电通信发展中、长期汁划；
3.	全国的邮电通信网路组织、枢纽分布，全国的邮电通信干线具体路由、图纸资料；
4.	省级备战通信总体布局、周站分布、枢纽设备、网路组织和通信能力；
5.	边防海防通信部署；
6.	党政电话专用通信组织和通信设施；
7.	为党和国家领导任提供的特设通信服务手段和为外国政府要员再中国境内活动提供的专用通信方案；
8.	为军事部门提供的通信保障，涉及重要国防科研任务的性质、目的和实施时间、地点和通信方案；
9.	为党政军领导部门提供的专用邮政通信服务的组织措施和传递方式；
10.	邮政机要通信的组织机构和通信状况（传递方式、运递时间、揭发频次、投递路线）；
11.	在邮电国际会议和双边活动中，涉及我国通信权益及与他国关系方面所采取的方针、策略；
12.	秘密渠道提供的技术资料和有关我国同境外通信合作关系的重要情报及其来源；
13.	未公开的具有国际先进水平的有点科技成果。
（三）秘密级事项
1. 近期全国有点通信发展具体计划；
2. 全国邮电通信财务计划和年度预算、决算；
3. 省（自治区、直辖市）的邮电通信发展规划；
4. 省（自治区、直辖市）的邮电通信网络组织、枢纽分布和干线具体路由、图纸资料；
5.邮电通信干线工程总体方案和通路组织；
6.调整邮电资费预案（含邮电资费制定依据和邮电通信产品成本测算数据）；
7.邮政电汇押密和邮政储蓄计算机存取密码；
8. 未公开的邮票、集邮品发行数量、库存数量和变价信息；
9.邮电引进技术、进口设备、利用外资的项目计划，进口设备选型意见、投资估算、签约前的价格方案、外汇控制额度、谈判策略；
10. 邮电通信工程招标工作中有关评标、选标方案；
11.	开办国际竞争性邮电通信业务的发展目标、措施和竞争对策；
12.	未公开的对外通信合作计划、协议、协定、备忘录、纪要；
13.	邮电通信引进项目中吸收创新部分的关键技术。
第三条  邮电工作中下列事项不属于国家秘密，但应当作内部事项管理不得擅自扩散：
(一)	不宜公开的对台邮电通信情况；
(二)	邮电涉外活动中的内部通报及内部规定；
(三)	邮电部门留成外汇数目及使用安排计划；
(四）	邮电业务规章、制度、简报、文件资料。
第四条  本规定自一九九零年元月十七日起生效，邮电部一九六四年十月二十七日制定的《邮电部门保守国家机密暂行条例》中“机密范围和机密等级划分规定”同时废止。
""",
    """如何区分宗教与邪教？\n\n来源：湖南省沅陵县反邪教协会 2016-10-13\n\n\n\n\n\n\n\n\n\n2014年震惊全国的山东招远全能神邪教杀人案主犯近日一审被判死刑（资料图）\n\n宗教是人类社会发展到一定历史阶段出现的一种文化现象，属于社会意识形态。宗教认为现实世界之外存在超自然的神秘力量或实体，该神秘力量能统摄万物而拥有绝对权威，主宰自然进化，决定人世命运，使人对神秘力量产生敬畏及崇拜，从而引申出信仰认知及仪式活动。邪教组织是冒用宗教名义或打着宗教旗号，歪曲宗教经典，掺杂迷信和伪科学内容，拚凑所谓“教义”，神化首要分子，以秘密传教方式发展成员，制造、散布歪理邪说，蒙骗、恐吓、胁迫群众的非法组织。\n\n在当今世界，邪教已经超出了宗教领域的教派问题，孽生为对社会稳定构成严重威胁的从事违法犯罪的地下邪恶势力。清代雍正皇帝曾说过：“所谓邪教者，非指世俗寻常僧道之流而言”，“大抵妄立名号，诳诱愚民，或巧作幻术，夜聚晓散。此等之人，党类繁多，踪迹诡秘。”近年来，美国、法国、日本、意大利等国采取法律措施，对“人民圣殿教”、“科学教”、“奥姆真理教”、“撒旦的孩子”等邪教组织进行严厉打击。邪教已经成为人类公敌，在世界上已如过街老鼠，人人喊打。自二十世纪八十年代以来，我国政府相继对“呼喊派”、“全能神”、“被立王”、“主神教”、“门徒会”、“法轮功”等邪教组织开展了长期的宣传揭批、帮助教育和查禁取缔工作，有效遏制了邪教组织的发展蔓延，维护了人民群众的生命财产安全和社会稳定。\n\n识别邪教祸世害人的真正面目，正确区分宗教与邪教的界限，已成为广大人民群众的共同愿望。\n\n一、宗教与社会基本相适应，邪教则与社会根本相对立。宗教倡导信徒融入社会，推崇道德，遵守法律，维护社会和谐，拥护现行政府及其社会制度。当国家遭遇自然灾害或发生战乱，宗教则举行祈祷仪式，为国家祈福，为天下苍生祈求平安。如佛教的“庄严国土，利乐有情”，天主教、基督教的“荣神益人”，道教的“齐同慈爱、济世度人”，伊斯兰教的“两世吉庆”等。这些说法虽然不尽相同，但都是引导信徒与社会相适应。邪教则反社会，反人类，反政府，反科学，蔑视法律，蛊惑煽动成员仇视社会，危害社会，甚至带有政治野心，鼓吹、煽动推翻政府和现行的社会体制。当国家发生重大变故，邪教则乘机作乱，为祸社会。如全能神邪教将一般民众视为“恶魔”、“邪灵恶神”，要求信徒共同将其消灭；门徒会邪教组织则将政府称为“黑政府”，社会是“黑社会”，扬言要砸烂“黑政府”，打倒“黑社会”，提出“先争人心，后夺政权”，与社会格格不入。\n\n二、宗教的崇拜对象属于历史传承，邪教的神化对象为教主自我标榜。宗教信仰和崇拜的对象是各个宗教特定的神(仙、佛)，是悠久历史的传承，是固定不变的。宗教信仰反对人自比神明和自吹具有“神力”。如天主教和基督教敬奉圣母和耶稣，伊斯兰教信奉真主安拉，佛教奉释迦牟尼为佛祖，道教奉老子为教祖。邪教崇拜的则是教主本人，邪教头子总是冒用神的名义，自称是神的“替身”、“代表”或“仆人”是神的“肉身再现”，只有他可以与神沟通，他才是至高无上的“神”、“主”、“活基督”，是世界的创造者、主宰者和救世主，并吹嘘自己有种种超常、特异的能力，神化自己，使成员产生神秘、敬畏感，对他顶礼膜拜和盲从，从而达到控制成员精神的目的。如全能神宣扬《圣经》中提到的耶和华的“法律时代”和耶稣的“恩典时代”已经过去，“全能神”统治的“国度时代”已经来临，只有信“全能神”才能消灾保平安。\n\n三、宗教依法公开活动，邪教则秘密结社，非法传教。我国宗教有合法登记的宗教团体组织和宗教活动场所，信教公民的集体宗教活动在政府登记和开放的宗教活动场所(如寺院、宫观、清真寺、教堂)内举行，由经宗教团体认定、政府宗教事务管理部门备案的宗教教职人员主持，严格按照教义教规进行。邪教采用地下秘密活动方式，传教、串联、聚会活动多在比较隐蔽的地点进行，活动诡秘。如同一个秘密王国，与黑社会组织十分相似。一旦加入邪教组织，就受到精神和人身自由的控制，很难摆脱出来。近几年来，被破获的邪教组织的“教主”和骨干全部使用假名、化名，用内部规定的暗语进行联系，平时在设有暗道的房间或地下室内活动。\n\n四、宗教有博大精深的经典教义，邪教的所谓教义则是危言耸听的歪理邪说。宗教有自己的沿袭历史传承的经典教义，如佛教的《大藏经》、道教的《道德经》、伊斯兰教的《古兰经》、天主教、基督教的《圣经》等。邪教所谓的教义都是盗用宗教用语编造危言耸听的歪理邪说，如法轮功的《转法轮》、门徒会的《闪光的灵程》、全能神的《东方发出的闪电》等等。\n\n五、宗教不允许神职人员个人敛财和行骗，邪教则用各种手段骗财、骗色，甚至胁迫信徒屈从。宗教的经费通过光明正大的劝募，如佛教的化缘、布施等；邪教则编造邪说恐吓信徒骗取钱财，甚至骗色。如全能神邪教鼓吹“世界末日论”，只有将钱财奉献出来，才能消灾保平安；门徒会邪教宣扬“一切靠神的恩赐”，信徒要将钱财奉献出来，可以吃“赐福粮”、“生命粮”，全能神邪教宣扬女性信徒要“过灵床”，通过输入高能量的物质，才能使信仰长进，其实质上就是编造邪说哄骗和奸淫妇女。
""",
]


def test_extract_keywords():
    for i, s in enumerate(docs):
        print('#{}: {}'.format(i + 1, s))
        for x, w in extract_keywords(s, with_weight=True):
            print(x, w)
